#
# spec file for package libdnf
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global libsolv_version 0.7.7
%global libmodulemd_version 2.5.0
%global librepo_version 1.11.0
%global dnf_conflict 4.2.13
%global swig_version 3.0.12

# Keep tests switched off for now, it bombs out on SUSE
%bcond_with check

# Keep valgrind tests switched off for now
%bcond_with valgrind

%define somajor 2
%define libname %{name}%{somajor}
%define devname %{name}-devel

Name:           libdnf
Version:        0.45.0
Release:        lp152.3.3
Summary:        Library providing C and Python APIs atop libsolv
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Url:            https://github.com/rpm-software-management/%{name}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# PATCH-FIX-OPENSUSE: Fix libdnf build with static libsolvext
Patch1000:      libdnf-0.39.1-with-static-libsolvext.patch
# PATCH-FIX-OPENSUSE: Switch default reposdir to /etc/dnf/repos.d
Patch1001:      libdnf-0.39.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
# PATCH-FIX-OPENSUSE: Handle monitoring non-bdb rpmdb variants
Patch1002:      libdnf-0.45.0-handle-all-rpmdb-variants.patch

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gpgme-devel
BuildRequires:  libsolv-devel >= %{libsolv_version}
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
%if %{with valgrind}
BuildRequires:  valgrind
%endif
BuildRequires:  rpm-devel >= 4.11.0
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.46.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
BuildRequires:  pkgconfig(smartcols)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zck) >= 0.9.11

# libsolv specific BRs
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

%description
This library provides a high level RPM package manager that can be integrated
into applications to manage software. It is currently used by DNF, RPM-OSTree,
and PackageKit.

%package -n %{libname}
Summary:        Library providing an interface atop libsolv
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}-%{release}
# gobject-introspection is no longer used
Obsoletes:      typelib-1_0-Dnf-1_0 < 0.24.1
# To avoid API issues with librepo and incomprehensible crashes
Requires:       librepo0%{?_isa} >= %{librepo_version}
# To avoid API issues with libmodulemd
Requires:       libmodulemd2%{?_isa} >= %{libmodulemd_version}

%description -n %{libname}
This library provides an interface atop libsolv, and a high-level
RPM package manager library interface.

%package -n python3-%{name}
Summary:        Python 3 bindings for the libdnf library
Group:          Development/Libraries/Python
Requires:       %{libname}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  swig >= %{swig_version}
Conflicts:      python3-dnf < %{dnf_conflict}

%description -n python3-%{name}
This package provides the Python 3 bindings for the libdnf library.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package provides the headers and libraries for developing applications
that use %{name}.

%package -n hawkey-man
Summary:        Documentation for the hawkey Python bindings
Group:          Documentation/Man
BuildRequires:  python3-Sphinx
BuildRequires:  python3-nose
BuildArch:      noarch

%description -n hawkey-man
This package provides the man pages for the hawkey Python bindings.

%package -n python3-hawkey
Summary:        Python 3 bindings for the hawkey interface
Group:          Development/Libraries/Python
BuildRequires:  python3-devel
BuildRequires:  python3-nose
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       python3-%{name}%{?_isa} = %{version}-%{release}
Recommends:     hawkey-man = %{version}-%{release}
Conflicts:      python3-dnf < %{dnf_conflict}
# Python 2 subpackage has been dropped
Obsoletes:      python2-hawkey < 0.24.1

%description -n python3-hawkey
This package provides the Python 3 bindings for %{name} through
the hawkey interface.

%lang_package


%prep
%autosetup -p1

# Fix sphinx-build run...
sed -e "s/sphinx-build-3/sphinx-build-%{python3_version}/" -i docs/hawkey/CMakeLists.txt

%build
%cmake -DPYTHON_DESIRED:FILEPATH=%{__python3} %{!?with_valgrind:-DDISABLE_VALGRIND=1}
%make_build

%if %{with check}
%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}

if [ "$(id -u)" == "0" ] ; then
        cat <<ERROR 1>&2
Package tests cannot be run under superuser account.
Please build the package as non-root user.
ERROR
        exit 1
fi
pushd build
  make ARGS="-V" test
popd

%endif

%install
pushd build
  %make_install
popd

%find_lang %{name}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname} -f %{name}.lang
%license COPYING
%doc README.md AUTHORS
%{_libdir}/%{name}.so.%{somajor}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/README

%files -n python3-%{name}
%{python3_sitearch}/%{name}/

%files -n %{devname}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_datadir}/gtk-doc/html/%{name}/

%files -n hawkey-man
%{_mandir}/man3/hawkey.3*

%files -n python3-hawkey
%{python3_sitearch}/hawkey/

%changelog
* Mon Mar 23 2020 Neal Gompa <ngompa13@gmail.com>
- Remove unused BR for gobject-introspection
* Sun Mar 22 2020 Neal Gompa <ngompa13@gmail.com>
- Add patch to support monitoring non-bdb rpmdb variants
  + Patch: libdnf-0.45.0-handle-all-rpmdb-variants.patch
* Thu Feb 27 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.45.0
  + Config options: only first empty value clears existing (rh#1788154)
  + Make parsing of reldeps more strict (rh#1788107)
  + [context] Support repositories defined in main configuration file
  + Fix filtering packages by advisory when more versions and arches are available (rh#1770125)
  + Add expanding solvable provides for dependency matching (rh#1534123)
  + DnfRepo: fix module_hotfixes keyfile priority level
  + Add custom exceptions to libdnf interface
  + [conf] Set useful default colors when color is enabled
  + Port to libmodulemd-2 API (rh#1693683)
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.43.1
  + Allow excluding packages with "excludepkgs" and globs
  + Add two new query filters: obsoletes_by_priority, upgrades_by_priority
  + [context] Use installonly_limit from global config (rh#1256108)
  + [context] Add API to get/set "install_weak_deps"
  + [context] Add wildcard support for repo_id in dnf_context_repo_enable/disable (rh#1781420)
  + [context] Adds support for includepkgs in repository configuration.
  + [context] Adds support for excludepkgs, exclude, includepkgs, and disable_excludes in main configuration.
  + [context] Added function dnf_transaction_set_dont_solve_goal
  + [context] Added functions dnf_context_get/set_config_file_path
  + [context] Respect "plugins" global conf value
  + [context] Add API to disable/enable plugins
* Sun Dec  1 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.39.1
  + Skip invalid key files in "/etc/pki/rpm-gpg" with warning (rh#1644040)
  + Enable timestamp preserving for downloaded data (rh#1688537)
  + Set default to skip_if_unavailable=false (rh#1679509)
  + Add configuration option skip_if_unavailable (rh#1689931)
  + Fix 'database is locked' error (rh#1631533)
  + Replace the 'Failed to synchronize cache' message (rh#1712055)
  + Fix 'no such table: main.trans_cmdline' error (rh#1596540)
  + Add support of modular FailSafe (rh#1623128) (temporarily with warnings
    instead of errors when installing modular RPMs without modular metadata)
  + Add support of DNF main config file in context; used by PackageKit and
    microdnf (rh#1689331)
  + Exit gpg-agent after repokey import (rh#1650266)
  + Don't disable nonexistent but required repositories (rh#1689331)
  + Fix toString() to not insert [] (rh#1584442)
  + Ignore trailing blank lines in config (rh#1722493)
  + Fix handling large number of filenames on input (rh#1690915)
  + Detect armv7 with crypto extension only on arm version >= 8
  + A new standardized User-Agent field consisting of the libdnf and OS version
    (including the variant) (rh#1156007)
  + Add basic countme support (rh#1647454)
  + Fix crash in PackageKit (rh#1636803)
  + Do not create @System.solv files (rh#1707995)
  + Set LRO_CACHEDIR so zchunk works again (rh#1739867)
  + Don't reinstall modified packages with the same NEVRA (rh#1644241)
  + Fix bug when moving temporary repository metadata after download (rh#1700341)
  + Improve detection of extras packages by comparing (name, arch) pair
    instead of full NEVRA (RhBuh:1684517)
  + Improve handling multilib packages in the history command (rh#1728637)
  + Repo download: use full error description into the exception text (rh#1741442)
  + Properly close hawkey.log (rh#1594016)
  + Fix dnf updateinfo --update to not list advisories for packages updatable
    only from non-enabled modules
  + Apply modular filtering by package name (rh#1702729)
  + Fully enable the modular fail safe mechanism (rh#1616167)
  + Use more descriptive message when failed to retrieve GPG key (rh#1605117)
  + Add removeMetadataTypeFromDownload function to the API
  + Context part of libdnf can now read vars (urlvars) from dirs and environment
  + Throw exception immediately if file cannot be opened
  + Add test when there is no primary metadata in compatible format (rh#1744960)
  + Don't abort on rpmdb checksum calculation failure
  + Enable module dependency trees when using set_modules_enabled_by_pkgset() (rh#1762314)
  + New method "Query::filterSubject()", replaces Solution::getBestSolution()
  + The Solution class was removed
  + Add query argument into get_best_query and get_best_solution
  + Add module reset function into dnf_context
  + Add method to get all repository metadata locations
  + Catch NoModuleException in case of not existent value was used in persistor (rh#1761773)
  + Handle NoModuleException in dnf_context_reset_modules (rh#1767453)
  + Report reason how package was excluded (rh#1649754)
  + Fix Arm detection improvements (rh#1691430)
  + Set skip_if_unavailable to true for all media repos (rh#1716067)
  + Only the pkg knows whether it is local or remote (rh#1734350, rh#1717865)
  + Don't use repo's packages as path to local pkgs (rh#1734350, rh#1717865)
- Drop patch for temporarily dropping support for module advisories
  * Patch: libdnf-0.31.0-Revert-support-for-Module-advisories.patch
- Refresh patches
  * Remove patch: libdnf-0.28.1-with-static-libsolvext.patch
  * Remove patch: libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  * Add patch: libdnf-0.39.1-with-static-libsolvext.patch
  * Add patch: libdnf-0.39.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Fri May 10 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.33.0
  + Import subkeys when importing GPG keys (gh#projectatomic/rpm-ostree#1094)
  + [module] Fix swig binding for getModuleDependencies() (rh#1704871)
  + [module] Prevent std::string from nullptr (gh#rpm-software-management/libdnf#717)
  + Reintroduce hawkey.Repo as deprecated class
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Add patch for SLE to temporarily drop support for Module advisories
  * Patch: libdnf-0.31.0-Revert-support-for-Module-advisories.patch
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.31.0
  + Installroot now requires absolute path
  + Support "_none_" value for repo option "proxy" (rh#1680272)
  + Add support for Module advisories
  + Add support for xml:base attribute from primary.xml (rh#1691315)
  + Fix detection of Platform ID for modules (rh#1688462)
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.28.1
  + Enhance modular solver to handle enabled and default module streams differently (rh#1648839)
  + Add support of wild cards for modules (rh#1644588)
  + Exclude module pkgs that have conflict
  + Enhance config parser to preserve order of data, and keep comments and format
  + Improve ARM detection
  + Add support for SHA-384
  + Return empty query if incorrect reldep (rh#1687135)
  + ConfigParser: Improve compatibility with Python ConfigParser and dnf-plugin-spacewalk (rh#1692044)
  + ConfigParser: Unify default set of string represenation of boolean values
  + Fix segfault when interrupting dnf process (rh#1610456)
- Drop backported patches that are part of this release
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patches
  * Remove patch: libdnf-0.24.1-with-static-libsolvext.patch
  * Remove patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  * Add patch: libdnf-0.28.1-with-static-libsolvext.patch
  * Add patch: libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
- Adjust RPM groups.
* Wed Feb 13 2019 Neal Gompa <ngompa13@gmail.com>
- Fix cmake macro pointer to source tree
* Thu Feb  7 2019 Neal Gompa <ngompa13@gmail.com>
- Switch default reposdir to /etc/dnf/repos.d
  * Add patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Tue Feb  5 2019 Neal Gompa <ngompa13@gmail.com>
- Rebase to version 0.24.1
  + Add support for RH/Fedora modules
  + Add plugin support (unstable API)
  + Add zchunk support
  + Migrate from YUMDB to new SWDB
  + Rewrite into C++
- Drop Python 2 bindings
- Backport fixes from upstream eliminate various bugs
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
- Add proposed patches for improving zchunk support
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patch for linking to static libsolvext
  * Remove patch: libdnf-0.9.3-with-static-libsolvext.patch
  * Add patch: libdnf-0.24.1-with-static-libsolvext.patch
- Drop patch merged in upstream libdnf
  * 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Aug 20 2018 Neal Gompa <ngompa13@gmail.com>
- Refresh patch to fix building against static libsolvext
- Switch to full author identities
* Thu Jan  4 2018 Neal Gompa <ngompa13@gmail.com>
- Ensure SUSE kernel packages are recognized properly
  * New patch: 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Nov 13 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.1:
  + Make NEVRA parsing stricter
  + Fix segfault with queries if epoch isn't set
  + Improve performance of queries of solvables
* Tue Oct 10 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.0:
  + Improves query performance with 'name' and 'arch' filters.
    Also 'nevra' filter will now handle string with or without
    'epoch'.
  + For Python bindings, it renames 'NEVRA._has_just_name()' to
    'NEVRA.has_just_name()' as it's now implemented in the C API.
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Fix building on openSUSE against static libsolvext
  * New patch: libdnf-0.9.3-with-static-libsolvext.patch
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia package
